@@ -35,6 +35,9 @@ class PopCommand(Command):
 
     def run(self, options, args):
         pop = Pop(os.getcwd(), self.get_pc_dir())
+        pop.unapplying.connect(self.unapplying)
+        pop.unapplied.connect(self.unapplied)
+        pop.empty_patch.connect(self.empty_patch)
 
         if options.all:
             pop.unapply_all()
@@ -42,3 +45,15 @@ class PopCommand(Command):
             pop.unapply_top_patch()
         else:
             pop.unapply_patch(args[0])
+
+    def unapplying(self, patch):
+        print "Removing patch %s" % patch.get_name()
+
+    def unapplied(self, patch):
+        if not patch:
+            print "No patches applied"
+        else:
+            print "Now at patch %s" % patch.get_name()
+
+    def empty_patch(self, patch):
+        print "Patch %s appears to be empty, removing" % patch.get_name()
