@@ -36,4 +36,12 @@ class RevertCommand(Command):
 
     def run(self, options, args):
         revert = Revert(os.getcwd(), self.get_pc_dir(), self.get_patches_dir())
+        revert.file_reverted.connect(self.file_reverted)
+        revert.file_unchanged.connect(self.file_unchanged)
         revert.revert_files(args, options.patch)
+
+    def file_reverted(self, file, patch):
+        print "Changes to %s in patch %s reverted" % (file.get_name(),
+                                                      patch.get_name())
+    def file_unchanged(self, file, patch):
+        print "File %s is unchanged" % file.get_name()
