@@ -25,17 +25,39 @@ class QuiltError(Exception):
 
 class NoPatchesInSeries(QuiltError):
 
+    def __init__(self, series):
+        self.series = series
+
     def __str__(self):
-        return "No patch in series file %s" % self.args[0].series_file
+        return "No patch in series"
 
 
 class NoAppliedPatch(QuiltError):
 
+    def __init__(self, series):
+        self.series = series
+
     def __str__(self):
-        return "No applied patch in file %s" % self.args[0].series_file
+        return "No patches applied"
 
 
 class AllPatchesApplied(QuiltError):
 
+    def __init__(self, series, top=None):
+        self.series = series
+        self.top = top
+
     def __str__(self):
-        return "All patches are already applied"
+        if not self.top:
+            return "All patches are already applied"
+        return "File series fully applied, ends at patch %s" % \
+                self.top.get_name()
+
+class UnknownPatch(QuiltError):
+
+    def __init__(self, series, patch):
+        self.series = series
+        self.patch = patch
+
+    def __str__(self):
+        return "Patch %s is not in series" % self.patch.get_name()
